/*
	getconf.c -- libgetconf main file
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define __GETCONF_INTERNAL
#include "getconf.h"

/***
 * getconf
 * The main getconf function. Returns -1 if an error occurred, 0 if
 * either getconf_config() returned FALSE or if the input file was
 * empty, or the number of read lines if everything went ok.
 */
int getconf(const t_getconf_data getconf_data[], const char *file,
	t_getconf_config getconf_config)
{
	char *s, *p;
	GFILE fd;
	int i, argc, argv_size, lineno, ok;
	char **argv;

	if ((p=malloc(1025))==NULL) {
		perror("malloc");
		return -1;
	}

	fd.line=1;
	if ((fd.fd=fopen(file,"r"))==NULL)
		return -1;

	argv_size=0;
	argv=NULL;
	lineno=0; /* to make gcc stop whining */
	do {
		i=0;
		forever {
			s=getconf_token(p,1024,&fd);
			if (i==0)
				lineno=fd.line;
			if ((s==NULL) || (strcasecmp(s,"\n")==0))
				break;

			if ((i+1)>argv_size) {
				argv_size+=1024;
				argv=realloc(argv,argv_size);
			}

			argv[i]=strdup(s);
			i++;
		}
		if (i>0) {
			argc=i;
			if (!(ok=getconf_func(getconf_config,getconf_data,argc,
					argv,lineno,file,&fd)))
				s=NULL;
			for (i=0; i<argc; i++)
				free(argv[i]);
		}
	} while (s!=NULL);

	fclose(fd.fd);

	free(p);
	free(argv);

	return ok? fd.line:0;
}

/* end getconf.c */
