/*
	getconf.h -- libgetconf main file
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef GETCONF_H_
#define GETCONF_H_ 1

/*
 * a somewhat weird getconf file abstraction, needed to get the line
 * numbering straight.
 */
typedef struct {
	FILE *fd;
	int line, prevline;
} GFILE;

#define GETCONF_CONFIG_PARAM (int number, int argc, char *argv[], \
	int lineno, const char *file, GFILE *fd)

typedef int (*t_getconf_config) GETCONF_CONFIG_PARAM;

typedef struct {
	char *name;
	int number;
} t_getconf_data;

#ifdef __GETCONF_INTERNAL

#define DELIMITERS	" \t:="
#define NEWLINE		"\r\n"
#define QUOTES		"\"'`"
#define ESCAPE		"\\"
#define COMMENT		"#;"

char *getconf_token(char *buf, int size, GFILE *fd);
int getconf_func(t_getconf_config getconf_config,
	const t_getconf_data getconf_data[], int argc, char *argv[],
	int lineno, const char *file, GFILE *fd);

#endif /* __GETCONF_INTERNAL */

int getconf_fgetc(GFILE *fd);
int getconf_ungetc(int c, GFILE *fd);
char *getconf_fgets(char *s, int size, GFILE *fd);

int getconf(const t_getconf_data getconf_data[], const char *file,
	t_getconf_config getconf_config);

#endif

#ifndef TRUE
# define TRUE (1==1)
#endif /* TRUE */

#ifndef FALSE
# define FALSE (1==0)
#endif /* FALSE */

#ifndef forever
# define forever for(;;)
#endif /* forever */

/* end getconf.h */
