/*
	io.c -- libgetconf I/O routines
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define __GETCONF_INTERNAL
#include "getconf.h"

/***
 * getconf_fgetc
 * Function to read a single character from a getconf-ized
 * stream. This function also records the current line number, so
 * error reports in the config_func() can be accurate regarding
 * the line number of the error.
 */
int getconf_fgetc(GFILE *fd)
{
	char c;

	if ((c=fgetc(fd->fd))=='\n') {
		fd->prevline=fd->line;
		fd->line++;
	}

	return c;
}

/***
 * getconf_ungetc
 * Getconf-ized ungetc().
 */
int getconf_ungetc(int c, GFILE *fd)
{
	if (c=='\n')
		fd->line=fd->prevline;

	return ungetc(c,fd->fd);
}

/***
 * getconf_fgets
 * Getconf-ized fgets().
 */
char *getconf_fgets(char *s, int size, GFILE *fd)
{
	int i;
	char c;

	i=0;
	while (i<size) {
		if ((c=getconf_fgetc(fd))==EOF)
			break;
		*(s+i)=c;
		if (c=='\n')
			break;
		i++;
	}
	*(s+i)='\0';

	if (ferror(fd->fd))
		return NULL;
	return s;
}

/* end io.c */
