/*
	token.c -- string tokenizer for getconf
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define __GETCONF_INTERNAL
#include "getconf.h"

/***
 * getconf_token
 * The getconf string tokenizer.
 */
char *getconf_token(char *buf, int size, GFILE *fd)
{
	char c;
	int quotes, len, comment;

	if (feof(fd->fd) || (buf==NULL))
		return NULL;

	quotes=FALSE;
	comment=FALSE;
	*buf='\0';
	len=0;
	forever {
		c=getconf_fgetc(fd);
		if (c==EOF)
			break;

		if (comment) {
			if (strchr(ESCAPE,c)!=NULL) {
				if (strchr(NEWLINE,getconf_fgetc(fd))!=NULL)
					continue;
			}
			if (strchr(NEWLINE,c)!=NULL)
				comment=FALSE;
		} else if ((!quotes) && (strchr(DELIMITERS,c)!=NULL)) {
			if (len==0)
				continue;
			else
				break;
		} else if (strchr(QUOTES,c)!=NULL) {
			if (!quotes) {
				if (len==0) {
					quotes=TRUE;
				} else {
					getconf_ungetc(c,fd);
					break;
				}
			} else {
				quotes=FALSE;
				break;
			}
		} else if (strchr(NEWLINE,c)!=NULL) {
			if (len==0) {
				*buf='\n';
				len++;
				break;
			} else {
				getconf_ungetc(c,fd);
				break;
			}
		} else if ((!quotes) && (strchr(COMMENT,c)!=NULL)) {
			comment=TRUE;
		} else {
			if (strchr(ESCAPE,c)!=NULL) {
				c=getconf_fgetc(fd);
				if (strchr(NEWLINE,c)!=NULL)
					continue;
			}
			strncat(buf,&c,1);
			len++;
		}
		if (len==size)
			break;
	}

	if (feof(fd->fd) && (len==0))
		return NULL;

	*(buf+len)='\0';

	return buf;
}

/* end token.c */
