/*
	cmdline.h -- command line parser for OMTA
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef CMDLINE_H_
#define CMDLINE_H_ 1

#include "address.h"

#define MODE_PLAIN	0
#define MODE_SMTP	1
#define MODE_DAEMON	2
#define MODE_XFER	3
#define MODE_DUMP	4

#define MODE_NOMODE	5	/* don't read the configuration file when */
#define MODE_HELP	5	/* any mode above MODE_NOMODE is selected */
#define MODE_SHORTHELP	6	/* as this would be senseless.            */
#define MODE_VERSION	7
#define MODE_DEFAULTS	8

extern char *myself;
extern t_address *from, *to;

void help();
void short_help();
void short_version();
void version();
int cmdline(int argc, char *argv[]);

#ifdef CMDLINE_HAVE_DATA

#include "omta.h"

static struct option long_options[]=
{
	{ "help",	no_argument, &mode, MODE_HELP },
	{ "version",	no_argument, &mode, MODE_VERSION },
	{ "default",	no_argument, &mode, MODE_DEFAULTS },

	{ "daemon",	no_argument, &mode, MODE_DAEMON },
	{ "smtp",	no_argument, &mode, MODE_SMTP },
	{ "plain",	no_argument, &mode, MODE_PLAIN },
	{ "dump",	no_argument, &mode, MODE_DUMP },
	{ "transfer",	no_argument, &mode, MODE_XFER },

	{ "config",	required_argument, 0, 'C' },
	{ "ignore-dots",no_argument, 0, 'i' },

	{ "from",	required_argument, 0, 'f' },
	{ "from-name",	required_argument, 0, 'F' },

	{ "log-dialog",	no_argument,	0,	'd' },
	{ "silent",	no_argument,	0,	's' },
	{ "log-level",	required_argument,0,	'l' },

	{ NULL, 0, NULL, 0 }
};

#define SHORT_OPTIONS "hvb:itq::o:C:Df:F:dsl:"

#endif /* CMDLINE_HAVE_DATA */

#endif

/* end cmdline.h */
