/*
	header.c -- RFC822 compatible parser for message headers
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "config-wrap.h"

#include "header.h"
#include "lib.h"

/***
 * header_alloc
 * Allocate a t_header struct, optionally assigining it a string.
 */
t_header *header_alloc(const char *str)
{
	t_header *header;

	header=calloc(sizeof(t_header),1);
	if (str!=NULL)
		header_assign(header,str);

	return header;
}

/***
 * header_free
 * Free the given t_header struct and return NULL.
 */
t_header *header_free(t_header *header)
{
	if (header!=NULL) {
		if (header->name!=NULL)
			free(header->name);
		if (header->content!=NULL)
			free(header->content);
		free(header);
	}

	return NULL;
}

/***
 * header_assign
 * Assign a string to a t_header struct.
 */
t_header *header_assign(t_header *header, const char *str)
{
	char *name, *content, *s;

	s=strdup(str);

	name=s;
	content=strchr(name,':');
	*content='\0';

	content=trim(content+1," \t");

	header->name=strdup(name);
	header->content=strdup(content);

	free(s);

	return header;
}

/***
 * header_create
 * Quickly create a t_header struct, taking folden headers into account.
 */
t_header *header_create(const char *str, t_header *last_header)
{	
	char *s, *p, *n;
	int l;

	if ((last_header!=NULL) && (strchr(" \t",*str)!=NULL)) {
		s=trim(p=strdup(str)," \t");

		l=strlen(s)+strlen(last_header->content)+1;
		n=stralloc(l);
		strncpy(n,last_header->content,l);
		strncat(n," ",l);
		strncat(n,s,l);

		free(last_header->content);
		last_header->content=n;

		free(p);

		return last_header;
	} else {
		return header_alloc(str);
	} 
}

/* end header.c */
