/*
	log.c -- logging routines for OMTA
	(C) Wouter Coene, 1999
	Based on log.c (C) Sam Roberts, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "config-wrap.h"
#include <stdarg.h>
#include <syslog.h>

#include "log.h"
#include "omta.h"
#include "lib.h"

int log_level=OLOG_DEFAULT;
int log_to_stderr=OLOG_STDERR;

/***
 * vlog
 * Generic logging function
 */
void vlog(int level, const char *fmt, va_list arglist)
{
	int priority, facility;
	char *buf;

	if (level==OLOG_NONE)
		return;
#ifdef NDEBUG
	if ((level==OLOG_DEBUG) || (level==OLOG_FUNC))
		return;
#endif

	if ((log_level & level)>0) {
		facility=LOG_MAIL;
		switch(level) {
			case OLOG_DIALOG:
				priority=LOG_NOTICE;
				break;

			case OLOG_ERROR:
				priority=LOG_ERR;
				break;

			case OLOG_DEBUG:
			case OLOG_FUNC:
				priority=LOG_DEBUG;
				break;

			default:
				priority=LOG_INFO;
		}
		if ((log_to_stderr & level)>0) {
			vfprintf(stderr,fmt,arglist);
		} else {
			buf=stralloc(MAX_LINE_LEN);
			vsnprintf(buf,MAX_LINE_LEN-1,fmt,arglist);
			syslog(facility|priority,buf);
			free(buf);
		}
	}
}

/***
 * log
 * Wrapper for vlog().
 */
void log(int level, const char *fmt, ...)
{
	va_list arglist;

	va_start(arglist,fmt);
	vlog(level,fmt,arglist);
	va_end(arglist);
}

#ifndef __GNUC__

log_alias(log_status,OLOG_STATUS)
log_alias(log_dialog,OLOG_DIALOG)
log_alias(log_error,OLOG_ERROR)
log_alias(log_debug,OLOG_DEBUG)

#endif

/* end log.c */
