/*
	message.h -- generic message handling
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef MESSAGE_H_
#define MESSAGE_H_ 1

#include <netinet/in.h>

#include "address.h"
#include "line.h"
#include "header.h"

#define MESSAGE_SIGNATURE	"$OMTA$V"
#define MESSAGE_VERSION		1
#define MESSAGE_OLDDELIM	", "

#define MSGERROR_OK		0
#define MSGERROR_NOSPACE	552

typedef struct {
	t_address *from, *to, *end_to;
	t_line *body, *end_body;
	int bytes, body_bytes;
	int lines, body_lines;
	int parse, error;
	char *helo, *id;
	struct in_addr from_host;

	t_header *__last_header;
} t_message;

t_message *message_alloc();
t_message *message_free(t_message *message);
t_message *message_set_sender(t_message *message, t_address *sender);
t_message *message_add_recipient(t_message *message, t_address *recipient);
t_message *message_add_recipients(t_message *message, t_address *recipient);
t_message *message_remove_recipients(t_message *message, t_address *recipient);
t_message *message_set_helo(t_message *message, const char *str);
t_message *message_add_body_raw(t_message *message, t_line *line, t_line *where, int prepend);
t_message *message_add_body(t_message *message, const char *str, int is_header);
int message_out(t_message *message, FILE *fd);
int message_write(t_message *message, FILE *fd);
t_message *message_read(FILE *fd, int do_body);

#endif

/* end message.h */
