/*
	omta.c -- main OMTA routines
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define WANT_UNISTD
#include "config-wrap.h"
#include <sys/socket.h>

#include "omta.h"
#include "mailer.h"
#include "address.h"
#include "daemon.h"
#include "queue.h"
#include "smtpserv.h"
#include "cmdline.h"
#include "readconf.h"
#include "log.h"
#include "lib.h"

int mode;
int scan_message=FALSE;
int ignore_period=FALSE;
int do_fork=FALSE;

/***
 * init
 * Global initialization routine.
 */
void init()
{
	setlinebuf(stdin);
	setlinebuf(stdout);

	lib_init();
}

/***
 * mode_plain
 * Plain mode handler.
 */
int mode_plain()
{
	t_message *message;
	int reverse, ok;

	reverse=FALSE;
	if ((to==NULL) && (!scan_message)) {
		printf("%s... Recipient names must be specified\n",user);
		scan_message=TRUE;
	} else if (scan_message) {
		reverse=TRUE;
	}

	message=message_alloc();

	if ((from!=NULL) && (conf.from_address==NULL))
		message_set_sender(message,from);

	if ((to!=NULL) && (!reverse)) {
		message_add_recipients(message,to);
	}

	message=mailer_get_message(message,stdin,message->to==NULL,!ignore_period);

	if ((reverse) && (to!=NULL))
		message_remove_recipients(message,to);

	if (conf.from_address!=NULL)
		message_set_sender(message,address_alloc(conf.from_address));
	ok=mailer_send(message);
	message_free(message);

	return ok;
}

/***
 * mode_smtp
 * SMTP mode handler.
 */
int mode_smtp()
{
	struct sockaddr_in addr;
	unsigned int addr_len;

	if (to!=NULL) {
		printf("Useless parameters specified on command line\n");
		return FALSE;
	}

	addr_len=sizeof(addr);
	if (getpeername(fileno(stdin),(struct sockaddr *) &addr,&addr_len)<0) {
		addr.sin_addr.s_addr=0;
	}
	smtp_server(stdin,stdout,conf.smtp_greeting,addr.sin_addr.s_addr);

	return TRUE;
}

/***
 * defaults
 * Write compile-time defaults to standard output.
 */
void defaults()
{
	short_version();
	printf("Compile-time defaults:\n\n");

	printf("Global configuration file:\t\t" CONFIG_GLOBAL "\n");
	printf("Local (per-user) configuration file:\t" CONFIG_LOCAL "\n");
	printf("Queue directory:\t\t\t" CONF_QUEUE "\n");
}

/***
 * run_mode
 * Do something based on the specified operation mode.
 */
int run_mode(int mode)
{
	int ok;

	if (conf.host_name!=NULL)
		set_fqdn(conf.host_name);

	if (!conf.logging)
		log_level=OLOG_NONE;

	ok=FALSE;
	switch (mode) {
		case MODE_PLAIN:
			ok=mode_plain();
			break;

		case MODE_SMTP:
			ok=mode_smtp();
			break;

		case MODE_DAEMON:
			ok=mode_daemon();
			break;

		case MODE_DUMP:
			ok=mode_dump();
			break;

		case MODE_XFER:
			ok=mode_xfer();
			break;

		case MODE_HELP:
			help();
			ok=TRUE;
			break;

		case MODE_SHORTHELP:
			short_help();
			break;

		case MODE_VERSION:
			version();
			ok=TRUE;
			break;

		case MODE_DEFAULTS:
			defaults();
			ok=TRUE;
			break;
	}

	return ok;
}

/***
 * main
 * The startup routine.
 */
int main(int argc, char *argv[])
{
	int mode;

	init();
	mode=cmdline(argc,argv);
	if (mode<MODE_NOMODE) {
		/* make shure no local configuration is read when
		   in daemon mode */
		if (!config(mode==MODE_DAEMON))
			return 2;
	}

	return (run_mode(mode)? 0:1);
}

/* end omta.c */
