/*
	readconf.h -- configuration reading routines
	(C) Wouter Coene, 1999

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, write to the Free Software
	Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef READCONF_H_
#define READCONF_H_ 1

#define CONFIG_GLOBAL			"/etc/mail/omta.conf"
#define CONFIG_LOCAL			".omtarc"

#define HEADER_PREPEND			20
#define HEADER_APPEND			21
#define HEADER_SET			22
#define HEADER_UNIQUE			23
#define HEADER_ENFORCE			24
#define HEADER_REMOVE			25

typedef struct {
	/* HostName */
	char *host_name;

	/* QueueDirectory */
	char *queue_path;

	/* SMTPserver */
	char *smtp_server;
	int smtp_port;

	/* RelayTo */
	char *relay_host;
	int relay_port;

	/* Local */
	int local_count;
	char **local;

	/* LocalMTA */
	char *local_mta;

	/* RelayFor */
	int relay_for_count;
	char **relay_for;

	/* SMTPgreeting */
	char *smtp_greeting;

	/* ServerPort */
	int server_port;

	/* Interface */
	char *interface;

	/* AllowLocal */
	int allow_local;

	/* FromAddress */
	char *from_address;

	/* MaxMessageSize */
	int max_message_size;

	/* Logging */
	int logging;

	/* PrependHeader, AppendHeader, SetHeader,
	   UniqueHeader, EnforceHeader and RemoveHeader */
	int extra_header_count;
	char **extra_header;
	int *extra_header_type;

	/* security related */
	int insecure_spool;
	int insecure_mailer;
	int insecure_port;
	int is_local;
} t_config;

extern char *conf_global;
extern char *conf_local;
extern t_config conf;

int config(int no_local);

#ifdef CONFIG_HAVE_DATA

#include <netinet/in.h>
#include <getconf.h>
#include "mailer.h"

#define CONF_HOSTNAME		1
#define CONF_QUEUEDIR		2
#define CONF_SMTPSERVER		3
#define CONF_RELAYTO		4
#define CONF_LOCAL		5
#define CONF_LOCALMTA		6
#define CONF_RELAYFOR		7
#define CONF_SMTPGREET		8
#define CONF_SERVERPORT		9
#define CONF_INTERFACE		10
#define CONF_ALLOWLOCAL		11
#define CONF_FROMADDRESS	12
#define CONF_MAXMSGSIZE		13
#define CONF_LOGGING		14
#define CONF_LOGLEVEL		15

#define CONF_PREPENDHEADER	HEADER_PREPEND
#define CONF_APPENDHEADER	HEADER_APPEND
#define CONF_SETHEADER		HEADER_SET
#define CONF_UNIQUEHEADER	HEADER_UNIQUE
#define CONF_ENFORCEHEADER	HEADER_ENFORCE
#define CONF_REMOVEHEADER	HEADER_REMOVE

#define CONFIG_DEF_SERVER	"smtp.frob.org"
#define CONFIG_DEF_SMTPPORT	IPPORT_SMTP
#define CONFIG_DEF_GREETING	NAME " " VERSION \
				", by the OMTA people <" OMTA_LIST ">"

#define CONFIG_DEF_MAXMSGSIZE	(1024*1024)
#define CONFIG_DEF_LOGGING	TRUE

/*
 * all the available configuration settings
 */
t_getconf_data getconf_data[]=
{
	{ "HostName",		CONF_HOSTNAME },
	{ "QueueDirectory",	CONF_QUEUEDIR },
	{ "SMTPserver",		CONF_SMTPSERVER },
	{ "RelayTo",		CONF_RELAYTO },
	{ "Local",		CONF_LOCAL },
	{ "LocalMTA",		CONF_LOCALMTA },
	{ "RelayFor",		CONF_RELAYFOR },
	{ "SMTPgreeting",	CONF_SMTPGREET },
	{ "ServerPort",		CONF_SERVERPORT },
	{ "Interface",		CONF_INTERFACE },
	{ "AllowLocal",		CONF_ALLOWLOCAL },
	{ "FromAddress",	CONF_FROMADDRESS },
	{ "MaxMessageSize",	CONF_MAXMSGSIZE },
	{ "Logging",		CONF_LOGGING },
	{ "LogLevel",		CONF_LOGLEVEL },

	{ "PrependHeader",	CONF_PREPENDHEADER },
	{ "AppendHeader",	CONF_APPENDHEADER },
	{ "SetHeader",		CONF_SETHEADER },
	{ "UniqueHeader",	CONF_UNIQUEHEADER },
	{ "EnforceHeader",	CONF_ENFORCEHEADER },
	{ "RemoveHeader",	CONF_REMOVEHEADER },

	{ NULL,			0 }
};

#endif /* CONFIG_HAVE_DATA */

#endif

/* end readconf.h */
